# Green Agent

...

## How to develop

First time:

```sh
poetry install --with test dev
poetry shell
python -m ipykernel install --user --name green-agent
```

In general:

```sh
poetry shell
```

Notebooks:

```sh
jupyter notebook  # classic UI
jupyter lab  # modern UI
```
